Add removeExtras(String...) prototype per API review.

Per API review, adding a convenience prototype of the removeExtras method.

Bug: 28295516
Change-Id: Icc0e040516c06205540c5683bde16882a73a89d6
diff --git a/telecomm/java/android/telecom/Conference.java b/telecomm/java/android/telecom/Conference.java
index 1ce4ade..be04c90 100644
--- a/telecomm/java/android/telecom/Conference.java
+++ b/telecomm/java/android/telecom/Conference.java
@@ -24,6 +24,7 @@
 import android.util.ArraySet;
 
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collections;
 import java.util.List;
 import java.util.Locale;
@@ -779,9 +780,9 @@
     }
 
     /**
      * Removes an extra from this {@link Conference}.
      *
      * @param keys The key of the extra key to remove.
      */
     public final void removeExtras(List<String> keys) {
         if (keys == null || keys.isEmpty()) {
@@ -803,6 +804,15 @@
     }
 
     /**
+     * Removes extras from this {@link Conference}.
+     *
+     * @param keys The keys of the extras to remove.
+     */
+    public final void removeExtras(String ... keys) {
+        removeExtras(Arrays.asList(keys));
+    }
+
+    /**
      * Returns the extras associated with this conference.
      * <p>
      * Extras should be updated using {@link #putExtras(Bundle)} and {@link #removeExtras(List)}.
@@ -779,9 +780,9 @@
 
     /**
-     * Removes an extra from this {@link Conference}.
+     * Removes extras from this {@link Conference}.
      *
@@ -779,9 +780,9 @@
      *
-     * @param keys The key of the extra key to remove.
+     * @param keys The keys of the extras to remove.
      */
     public final void removeExtras(List<String> keys) {